@@ -56,6 +56,8 @@ typedef enum {
    STAT_SHAPE      = 1 << 11, /**< This client uses the shape extension. */
    STAT_SDESKTOP   = 1 << 12, /**< This client was minimized to show desktop. */
    STAT_FULLSCREEN = 1 << 13, /**< This client wants to be full screen. */
+   STAT_OPACITY    = 1 << 14, /**< This client has a fixed opacity. */
+   STAT_NOFOCUS    = 1 << 15  /**< Don't focus on map. */
 } StatusFlags;
 
 /** Colormap window linked list. */
@@ -291,5 +293,15 @@ void SendConfigureEvent(ClientNode *np);
  */
 void SendClientMessage(Window w, AtomType type, AtomType message);
 
+/** Set the opacity for active clients.
+ * @param str The opacity to use.
+ */
+void SetActiveClientOpacity(const char *str);
+
+/** Set the opacity range for inactive clients.
+ * @param str The opacity range to use.
+ */
+void SetInactiveClientOpacity(const char *str);
+
 #endif /* CLIENT_H */
 
