@@ -23,11 +23,14 @@ typedef enum {
    TOK_ACTIVEFOREGROUND,
    TOK_BACKGROUND,
    TOK_BORDER,
+   TOK_BUTTONCLOSE,
+   TOK_BUTTONMAX,
+   TOK_BUTTONMAXACTIVE,
+   TOK_BUTTONMIN,
    TOK_CLASS,
    TOK_CLOCK,
    TOK_CLOCKSTYLE,
    TOK_CLOSE,
-   TOK_CORNER,
    TOK_DESKTOPS,
    TOK_DESKTOP,
    TOK_DOCK,
@@ -53,6 +56,7 @@ typedef enum {
    TOK_MOVE,
    TOK_MOVEMODE,
    TOK_NAME,
+   TOK_OPACITY,
    TOK_OPTION,
    TOK_OUTLINE,
    TOK_PAGER,
