@@ -10,9 +10,10 @@
 #ifndef MAIN_H
 #define MAIN_H
 
+/** Enumeration of focus models. */
 typedef enum {
-	FOCUS_SLOPPY              = 0,
-	FOCUS_CLICK               = 1
+   FOCUS_SLOPPY              = 0,
+   FOCUS_CLICK               = 1
 } FocusModelType;
 
 extern Display *display;
@@ -27,6 +28,8 @@ extern int colormapCount;
 
 extern char *exitCommand;
 
+extern unsigned int desktopWidth;
+extern unsigned int desktopHeight;
 extern unsigned int desktopCount;
 extern unsigned int currentDesktop;
 
@@ -51,6 +54,9 @@ extern XContext frameContext;
 extern int haveShape;
 extern int shapeEvent;
 #endif
-
+#ifdef USE_XRENDER
+extern int haveRender;
 #endif
 
+#endif /* MAIN_H */
+
